@@ -126,7 +126,7 @@ extern struct channel *getchptr(char *);
 extern struct chanuser *userjoined(char *, char *, char *, int, int, int);
 extern struct chanuser *getcuptr(char *, char *);
 extern struct state *emptystate(void);
-extern struct server *addnewserver(char *, int, int, int, int, int);
+extern struct server *addnewserver(char *, int, int, int, int, int, char *);
 extern struct server *getserver(void);
 extern struct advert *addnewadvert(char *, char *, char *);
 extern struct maskstruct *addnewmask(char *);
