@@ -36,6 +36,7 @@ int isaction(char *);
 int isctcp(char *);
 int wordcount(char *);
 int parse(char *, int, char *, char *, int, int);
+int issamenickandhost(char *, char *, char *, char *);
 void striplf(char *);
 void stripchars(char *, char *);
 void stripcntrl(char *);
@@ -427,3 +428,14 @@ void secondstostring(time_t seconds, char *string, int maxlen)
 		fields++;
         }
 }
+
+int issamenickandhost(char *n1, char *n2, char *h1, char *h2)
+{
+        if(n1 == NULL || n2 == NULL || h1 == NULL || h2 == NULL) {
+		return 0;
+	}
+	if(!strcasecmp(n1, n2) && !strcasecmp(n1, n2) && !strcasecmp(h1, h2)) {
+		return 1;
+	}
+	return 0;
+}
