@@ -51,6 +51,9 @@ int main(int argc, char *argv[])
         extern int opterr;
         extern int optopt;
 
+#ifdef HAVE_LOCALE_H
+	char *locptr;
+#endif
 	char stringbuffer[WRITE_BUFFER_LENGTH + 1];
 	int retval;
 	int c;
@@ -101,6 +104,12 @@ int main(int argc, char *argv[])
 	if(do_version) {
 		exit(EXIT_SUCCESS);
 	}
+#ifdef HAVE_LOCALE_H
+	if((locptr = setlocale(LC_CTYPE, "")) == NULL) {
+		oer_debug(OER_DEBUG_FATAL, "main->setlocale() failed for %s\n");
+                exit(EXIT_FAILURE);
+        }
+#endif
 	if(!do_console) {
 		oer_debug(OER_DEBUG_INFO, "main->oer calling fork()\n");
 		newpid = fork();
