@@ -286,6 +286,11 @@ void parseirc(char *serveroutput)
 		oer_debug(OER_DEBUG_INFO, "parseirc(441)->%s\n", restptr);
                 return;
         }
+	if(!strcasecmp(command, "464")) {
+		oer_debug(OER_DEBUG_INFO, "parseirc(464)->server reports bad password (%s)\n", (strlen(mystate->current_server->password)) ? mystate->current_server->password : "null");
+		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+		return;
+	}
 	if(!strcasecmp(command, "467")) {
 		/* channel key already set */
 		return;
@@ -1042,7 +1047,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 			if(u == NULL) {
 				return;
 			}
-			snprintf(outstring, WRITE_BUFFER_LENGTH, "random ban kick by %s\n", nick);
+			snprintf(outstring, WRITE_BUFFER_LENGTH, "random kick by %s\n", nick);
 			kickuser(channel, u->nick, outstring);
 		}
 		return;
